#pragma interface
#ifndef fetchmailconf_h
#define fetchmailconf_h
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>

class DICTIONARY;
class USERACCT_COMNG;

class MODULE_fetchmailconf: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_fetchmailconf */
public:
	MODULE_fetchmailconf (void);
	int dohtml (const char *key);
	int domenu (MENU_CONTEXT context,
		 const char *key);
	int execmain (int argc,
		 char *argv[],
		 bool);
	int message (const char *msg,
		 int argc,
		 const char *argv[]);
	int probe (int level,
		 int target,
		 bool simulation);
	void setmenu (DIALOG&dia,
		 MENU_CONTEXT context);
	void usage (SSTRINGS&tb);
    /*~PROTOEND~ MODULE_fetchmailconf */
};

#include "fetchmailconf.p"

extern CONFIG_FILE *f_config_file;

static const char K_BASICS[] = "basics";
static const char K_SCHEDULE[] = "schedule";
static const char K_LOG[] = "log";

#define K_SCHEDULE_MANUAL	0
#define K_SCHEDULE_CRON		1
#define K_SCHEDULE_DAEMON	2

#define K_LOG_STANDARD		0
#define K_LOG_SILENT		1
#define K_LOG_VERBOSE		2

#endif
